==> zen-cortex-7.0.4.tgz: package/constants/index.js <==
/**
 * Definitions of Web API partial actions type
 * */

//GET
export const READ_INIT = "_READ_REQUEST";
export const READ_DONE = "_READ_RESPONSE";
export const READ_FAIL = "_READ_FAILURE";

//POST
export const CREATE_INIT = "_CREATE_REQUEST";
export const CREATE_DONE = "_CREATE_RESPONSE";
export const CREATE_FAIL = "_CREATE_FAILURE";

//DELETE
export const DELETE_INIT = "_DELETE_REQUEST";
export const DELETE_DONE = "_DELETE_RESPONSE";
export const DELETE_FAIL = "_DELETE_FAILURE";

//PUT
export const UPDATE_INIT = "_UPDATE_REQUEST";
export const UPDATE_DONE = "_UPDATE_RESPONSE";
export const UPDATE_FAIL = "_UPDATE_FAILURE";

//PATCH
export const PATCH_INIT = "_PATCH_REQUEST";
export const PATCH_DONE = "_PATCH_RESPONSE";
export const PATCH_FAIL = "_PATCH_FAILURE";

/**
 * Definitions of statics action types
 * */

//authentication
export const USER_LOG_OUT = "USER_LOG_OUT";
export const USER_SESSION_RESTORE = "USER_SESSION_RESTORE";
export const USER_PASSWORD_CHANGE = "USER_PASSWORD_CHANGE";

//logging & notifications
export const MESSAGE_NOTIFY = "MESSAGE_NOTIFY";
export const MESSAGE_DISMISS = "MESSAGE_DISMISS";
export const MESSAGES_CLEAR = "MESSAGES_CLEAR";

//document constants
export const UPLOAD_DOCUMENT = "UPLOAD_DOCUMENT";
export const REPLACE_DOCUMENT = "REPLACE_DOCUMENT";
export const SNAPSHOT_DOCUMENT = "SNAPSHOT_DOCUMENT";

//history
export const HISTORY_USER_DISCONNECT = "HISTORY_USER_DISCONNECT";

//entity loading, selection, deletion, download & co
export const ENTITIES_API = "ENTITIES";
export const DELETE_ENTITIES = `${ENTITIES_API}_DELETE`;
export const SEND_ENTITIES = `${ENTITIES_API}_SEND`;
export const REFRESH_ENTITIES = `${ENTITIES_API}_REFRESH`;

==> zen-cortex-7.2.0.tgz: package/constants/index.js <==
/**
 * Definitions of Web API partial actions type
 * */

//GET
export const READ_INIT = "_READ_REQUEST";
export const READ_DONE = "_READ_RESPONSE";
export const READ_FAIL = "_READ_FAILURE";

//POST
export const CREATE_INIT = "_CREATE_REQUEST";
export const CREATE_DONE = "_CREATE_RESPONSE";
export const CREATE_FAIL = "_CREATE_FAILURE";

//DELETE
export const DELETE_INIT = "_DELETE_REQUEST";
export const DELETE_DONE = "_DELETE_RESPONSE";
export const DELETE_FAIL = "_DELETE_FAILURE";

//PUT
export const UPDATE_INIT = "_UPDATE_REQUEST";
export const UPDATE_DONE = "_UPDATE_RESPONSE";
export const UPDATE_FAIL = "_UPDATE_FAILURE";

//PATCH
export const PATCH_INIT = "_PATCH_REQUEST";
export const PATCH_DONE = "_PATCH_RESPONSE";
export const PATCH_FAIL = "_PATCH_FAILURE";

/**
 * Definitions of statics action types
 * */

//authentication
export const USER_AUTH = "AUTH";
export const USER_AUTH_PWD = "AUTH_PWD";
export const USER_LOG_OUT = "USER_LOG_OUT";
export const USER_SESSION_RESTORE = "USER_SESSION_RESTORE";

//logging & notifications
export const MESSAGE_NOTIFY = "MESSAGE_NOTIFY";
export const MESSAGE_DISMISS = "MESSAGE_DISMISS";
export const MESSAGES_CLEAR = "MESSAGES_CLEAR";

//document constants
export const UPLOAD_DOCUMENT = "UPLOAD_DOCUMENT";
export const REPLACE_DOCUMENT = "REPLACE_DOCUMENT";
export const SNAPSHOT_DOCUMENT = "SNAPSHOT_DOCUMENT";

//history
export const HISTORY_USER_DISCONNECT = "HISTORY_USER_DISCONNECT";

//entity loading, selection, deletion, download & co
export const ENTITIES_API = "ENTITIES";
export const DELETE_ENTITIES = `${ENTITIES_API}_DELETE`;
export const SEND_ENTITIES = `${ENTITIES_API}_SEND`;
export const REFRESH_ENTITIES = `${ENTITIES_API}_REFRESH`;
